@@ -1,6 +1,6 @@
-from fusil.mangle import MangleFile
+from fusil.mangle import MangleAgent
 
-class DummyMangle(MangleFile):
+class DummyMangle(MangleAgent):
     def mangleData(self, data, file_index):
         return data
 
