@@ -1,13 +1,27 @@
+"""
+Functions to recompute (fix) CRC32 checksums of an PNG picture.
+"""
+
 from array import array
 from StringIO import StringIO
-from fusil.bits import str2long, BIG_ENDIAN, long2raw
+from fusil.bits import bytes2uint, BIG_ENDIAN, uint2bytes
 from zlib import crc32
 from logging import info
 
 def pngCRC32(data):
+    """
+    Compute the CRC32 of specified data (str) as an unsigned integer.
+    """
     return crc32(data) & 0xFFFFFFFF
 
 def fixPNG(data):
+    """
+    Fix a mangled PNG picture:
+     - Rewrite PNG header (first 8 bytes)
+     - Recompute CRC32 of each PNG chunk
+
+    Stop if a chunk length is invalid.
+    """
     # array -> str
     data = data.tostring()
 
@@ -21,19 +35,15 @@ def fixPNG(data):
     index = 8
     while index < (datalen-4):
         data.seek(index)
-        size = str2long(data.read(4), BIG_ENDIAN)
+        size = bytes2uint(data.read(4), BIG_ENDIAN)
         chunksize = size+12
         if datalen < (index+chunksize):
             info("fixPNG: Skip invalid chunk at %s" % index)
             break
-        crcofs = index+chunksize-4
-        data.seek(crcofs)
-        oldcrc = data.read(4)
 
         data.seek(index+4)
-        o = data.tell()
         crcdata = data.read(chunksize-8)
-        newcrc = long2raw(pngCRC32(crcdata), BIG_ENDIAN, 4)
+        newcrc = uint2bytes(pngCRC32(crcdata), BIG_ENDIAN, 4)
 
         data.seek(index+chunksize-4)
         data.write(newcrc)
