@@ -1,4 +1,4 @@
-from ptrace.linux_proc import iterProc, readProcessProc, getSystemBoot, ProcError
+from ptrace.linux_proc import openProc, readProcessStat, getSystemBoot, ProcError
 from os import sysconf
 from fusil.tools import listDiff, timedeltaSeconds, minmax
 from datetime import datetime, timedelta
@@ -17,7 +17,7 @@ HERTZ = sysconf(_SC_CLK_TCK)
 
 SYSLOAD_MIN_CYCLES = HERTZ // 2         # 500 ms
 CPULOAD_MIN_CYCLES = HERTZ // 10        # 100 ms
-SYSLOAD_SLEEP = 0.100 # 100 ms
+SYSLOAD_SLEEP = 0.500                   # 500 ms
 
 class CpuLoad:
     def __init__(self):
@@ -52,11 +52,14 @@ class SystemCpuLoadValue(CpuLoadValue):
     def __init__(self):
         CpuLoadValue.__init__(self)
         self.data = None
-        for data in iterProc('stat'):
+        stat_file = openProc('stat')
+        for data in stat_file:
             # Look for "cpu ..." line
             if not data.startswith("cpu "):
                 continue
             self.data = [ max(int(item), 0) for item in data.split()[1:] ]
+            break
+        stat_file.close()
         if not self.data:
             raise CpuLoadError("Unable to get system load!")
 
@@ -94,13 +97,9 @@ class SystemCpuLoad(CpuLoad):
 class ProcessCpuLoadValue(CpuLoadValue):
     def __init__(self, pid):
         CpuLoadValue.__init__(self)
-        stat = readProcessProc(pid, 'stat')
-        stat = stat.rsplit(')', 1)[1]
-        stat = stat.split()
-        utime = int(stat[11])
-        stime = int(stat[12])
-        self.start_time = int(stat[19])
-        self.tics = utime + stime
+        stat = readProcessStat(pid)
+        self.start_time = stat.starttime
+        self.tics = stat.utime + stat.stime
 
 class ProcessCpuLoad(CpuLoad):
     """
