@@ -58,8 +58,9 @@ class CreateProcess(ProjectAgent):
         self.use_x11 = False
         self.popen_args = {
             'stderr': STDOUT,
-            'close_fds': True,
         }
+        if not RUNNING_WINDOWS:
+            self.popen_args['close_fds'] = True
         self.stdin = stdin
 
     def init(self):
@@ -96,7 +97,7 @@ class CreateProcess(ProjectAgent):
         arguments[0] = locateProgram(arguments[0], raise_error=True)
         popen_args = self.createPopenArguments()
         self.info("Create process: %s" % repr(arguments))
-        self.info("Working directoty: %s" % self.getWorkingDirectory())
+        self.info("Working directory: %s" % self.getWorkingDirectory())
         self.writeReplayScripts(arguments, popen_args)
         try:
             self.current_arguments = arguments
