@@ -1,6 +1,6 @@
 from fusil.xhost import xhostCommand
 from fusil.write_code import WriteCode
-from sys import executable, getfilesystemencoding
+from sys import executable, getfilesystemencoding, path as sys_path
 from os.path import normpath
 import itertools
 from fusil.python_tools import RUNNING_PYTHON3
@@ -97,6 +97,14 @@ class WriteReplayScript(WriteCode):
         self.write(0, u'from optparse import OptionParser')
         self.emptyLine()
 
+    def setSysPath(self):
+        self.write(0, u'import sys')
+        self.write(0, u'sys.path = [')
+        for path in sys_path:
+            self.write(1, u'"%s",' % path)
+        self.write(1, u']')
+        self.emptyLine()
+
     def limitResources(self):
         self.write(0, 'if options.limit:')
         self.write(1, 'return')
@@ -361,7 +369,6 @@ class WriteReplayScript(WriteCode):
 
         self.write(0, u'arguments = [')
         # Use relative PATH in arguments
-        command = []
         for arg in arguments:
             arg = formatPath(arg, cwd, cwd_bytes)
             self.write(1, u'%s,' % arg)
@@ -416,6 +423,7 @@ class WriteReplayScript(WriteCode):
         filename = session.createFilename("replay.py")
         self.createFile(filename, 0755)
         self.pythonImports()
+        self.setSysPath()
         self.globalVariables(process, config, cwd, arguments, env)
         self.writeFunction('debug(message)', self.writeDebugFunction)
         self.writeFunction('parseOptions()', self.parseOptions)
